@@ -211,11 +211,30 @@ bool Book::Load(QString filename, bool full)
         }
     }
 
+    FunctionsScript = AddGenericFunctions(FunctionsScript);
+
     file.close();
     FileName = filename;
     return !xml.hasError();
 }
 
+QString Book::AddGenericFunctions(QString functions)
+{
+    QString res = functions.trimmed();
+    QString generic = "use_EnduranceRestore: function()  { \
+                           Player.SetEndurance(Player.GetEndurance() + Item.GetEnduranceRestore()); \
+                       }, \
+                       use_CombatskillDelta: function()  { \
+                           Player.SetTempCombatSkillDelta(Item.GetCombatskillDelta()); \
+                       },";
+    if (!res.isEmpty() && res.startsWith("({")){
+        res.insert(2, generic);
+    }else{
+        res = QString("({%1})").arg(generic.remove(generic.length()- 1, 1));
+    }
+    return res;
+}
+
 Choice* Book::ParseChoice(Section* section, QXmlStreamReader* reader)
 {    
     QString eName = reader->name().toString();
